# acceldata SDK

Acceldata SDK for instrumenting support in [ADOC](https://docs.acceldata.io/documentation/adoc-architecture-an-overview).

Refer to the [documentation](https://docs.acceldata.io/documentation/python) for details.
---

## Changelog

<!-- BEGIN CHANGELOG -->

Version Log
========================

26.5.0 (09/05/2026)
------------------
- Released **acceldata_sdk** version 26.5.0.
- Added `uid` field to Summary API response to align with backend changes.

<!-- END CHANGELOG -->

